function [A, B]=LatPolesolve(handles);
% Solve Full Order Lateral/Directional equations of motion just for the actuator
% and aircraft dynamics. This function is called by the Pole Placement.
% Update the GUI with feedback path gains to provide the desired system
% performance. Originally developed by Rees 2003, modified by
% Konstantinos Siliverdis 20-Aug-2004 

Adim=getappdata(0,'ATRANS');
A=Adim(1:11);

m=Adim(6);
g=Adim(13);
V=Adim(5);
Ix=Adim(7);
Iz=Adim(8);
Ixz=Adim(9);
Yv=Adim(14);
Yp=Adim(15);
Yr=Adim(16);
Yda=Adim(17);
Ydr=Adim(18);
Lv=Adim(19);
Lp=Adim(20);
Lr=Adim(21);
Lda=Adim(22);
Ldr=Adim(23);
Nv=Adim(24);
Np=Adim(25);
Nr=Adim(26);
Nda=Adim(27);
Ndr=Adim(28);
theta=(A(3)+A(4))*pi/180;

%   Aircraft Model
%       beta                p                   r             phi     

M = [   m                   0                   0               0
        0                  Ix                -Ixz               0
        0                -Ixz                  Iz               0
        0                   0                   0               1];
a =[    Yv  Yp+V*sin(theta)*m    Yr-m*V*cos(theta)  m*g*cos(theta)
        Lv                  Lp                  Lr              0
        Nv                  Np                  Nr              0
        0                   1           tan(theta)              0];

%       Aileron Rudder   
b =[    Yda       Ydr
        Lda       Ldr
        Nda       Ndr
        0           0];
A   =   inv(M)*a;
B   =   inv(M)*b;
C   =   eye(4);
D   =   zeros(4,2);

SYSac = ss(A,B,C,D,'inputname',{'Aileron' 'Rudder'},...
        'outputname',{'\beta' 'p' 'r' '\phi'});


%   retrieve values from GUI
AactNUM  =   str2num(get(handles.AactNUM, 'String'));
AactDEN  =   str2num(get(handles.AactDEN, 'String'));
RactNUM  =   str2num(get(handles.RactNUM, 'String'));
RactDEN  =   str2num(get(handles.RactDEN, 'String'));
    
%   Actuator Models
SYSactA =   tf(AactNUM, AactDEN);
SYSactR =   tf(RactNUM, RactDEN);

%APPEND all system blocks
SYS = append(SYSac, SYSactA, SYSactR);
%CONNECT all system blocks
Q   =   [   1   5
            2   6];
inputs = [  3  4];
outputs = [ 1   2   3   4];
SYSTEM = connect(SYS,Q,inputs,outputs);
[A,B,C,D] = ssdata(SYSTEM);

 %   get the values for Wdr, Zdr, Spiral mode, & Roll mode.
    Wdr         =   get(handles.Wdr,        'Value');
    Zdr         =   get(handles.Zdr,        'Value');
    SpiralMode  =   get(handles.SpiralMode, 'Value');
    RollMode    =   get(handles.RollMode,   'Value');
    
%   determine if the roots are 2 complex pairs or just 1 complex pair and 2 real roots
[Wn z]  =   damp(A);    
Z = get(handles.Z,'String');
if get(handles.SpiralMode,'ForegroundColor') == [0 0 0]
    SpiralType = 'Complex';
else
    SpiralType = 'Real';
end
if get(handles.Wdr,'ForegroundColor') == [0 0 0]
    DutchType = 'Complex';
else
    DutchType = 'Real';
end
switch SpiralType
    case 'Real' % solve for complex pair and 2 real roots
        k1   =   conv([1 SpiralMode],[1 RollMode]);
    case 'Complex' % solve for 2 complex pairs
        k1   =   [1 2*SpiralMode*RollMode  SpiralMode^2];
end
switch DutchType
    case 'Real' % solve for complex pair and 2 real roots
        k2   =   conv([1 Wdr],[1 Zdr]);
    case 'Complex' % solve for 2 complex pairs
        k2   =   [1 2*Zdr*Wdr Wdr^2];
end
k   =   tf([1],conv(k1,k2));
    roots = eig(k);

    K  =   place(A, B, roots);
    %   assign the new K values values to the GUI
    %   8 gains to be entered for Lat/Dir

        set(handles.KbetaA, 'String', round(K(1,1)*V*10000)/10000, 'Value', K(1,1)*V); 
        set(handles.KpA,    'String', round(K(1,2)*10000)/10000, 'Value', K(1,2)); 
        set(handles.KrA,    'String', round(K(1,3)*10000)/10000, 'Value', K(1,3)); 
        set(handles.KphiA,  'String', round(K(1,4)*10000)/10000, 'Value', K(1,4));
        set(handles.KbetaR, 'String', round(K(2,1)*V*10000)/10000, 'Value', K(2,1)*V); 
        set(handles.KpR,    'String', round(K(2,2)*10000)/10000, 'Value', K(2,2)); 
        set(handles.KrR,    'String', round(K(2,3)*10000)/10000, 'Value', K(2,3)); 
        set(handles.KphiR,  'String', round(K(2,4)*10000)/10000, 'Value', K(2,4));   
 
return